Installation
============

Internally in Equinor, ecl2df is distributed through Komodo and
nothing is needed besides activating Komodo.

See https://fmu-docs.equinor.com/docs/komodo/equinor_komodo_usage.html
for Komodo instructions.

On Linux computers outside Equinor, ecl2df should be installed from
https://pypi.org:

.. code-block:: console

  pip install ecl2df

For MacOS, the OPM dependency is not available from pypi, and OPM must be
compiled manually.
